@@ -43,14 +43,21 @@
 MclustBounded <- function(data, ...)
 {
   mc <- match.call()
+  #
+  data <- na.omit(data.matrix(data))
+  n <- nrow(data)
+  d <- ncol(data)
+  varname <- deparse(mc$data)
+  if(is.null(colnames(data)))
+    { if(d == 1) colnames(data) <- varname
+      else       colnames(data) <- paste0(varname, seq(d)) }
+  #
   obj <- densityMclustBounded(data, ...)
   if(is.null(obj)) return(obj)
   obj$call <- mc
   obj$density <- NULL
   obj$entropy <- with(obj, -rowSums(z * ifelse(z > 0, log(z), 0)))
-  obj$nce     <- with(obj, ifelse(G == 1, 0, mean(entropy/log(G), na.rm = TRUE)))
-  if(obj$d == 1) 
-    colnames(obj$data) <- deparse(mc$data)
+  obj$nce     <- with(obj, ifelse(G == 1, 0, mean(entropy, na.rm = TRUE)/log(G)))
   class(obj) <- c("MclustBounded", "densityMclustBounded")
   return(obj)
 }
