@@ -839,7 +839,8 @@ densityBounded <- function(data, G, modelName,
 tloglik <- function(data, modelName, G, 
                     lambda = 1, 
                     lbound = -Inf, ubound = +Inf, 
-                    epsbound, parameters, 
+                    epsbound = NULL, 
+                    parameters = NULL, 
                     ...)
 {
   # browser()
