@@ -12,6 +12,12 @@ FIXME: Check these declarations against the C/Fortran source code.
 */
 
 /* .Call calls */
+extern SEXP _mclustAddons_colMax(SEXP);
+extern SEXP _mclustAddons_colSum(SEXP);
+extern SEXP _mclustAddons_hypcube_lhs(SEXP, SEXP, SEXP, SEXP);
+extern SEXP _mclustAddons_hypcube_smc(SEXP, SEXP, SEXP, SEXP);
+extern SEXP _mclustAddons_inside_range(SEXP, SEXP);
+extern SEXP _mclustAddons_logsumexp_Rcpp(SEXP, SEXP);
 extern SEXP _mclustAddons_powerTransform(SEXP, SEXP, SEXP);
 extern SEXP _mclustAddons_rangepowerTransformDeriv_lb(SEXP, SEXP, SEXP, SEXP);
 extern SEXP _mclustAddons_rangepowerTransformDeriv_lub(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
@@ -19,12 +25,16 @@ extern SEXP _mclustAddons_rangepowerTransformDeriv_unb(SEXP, SEXP);
 extern SEXP _mclustAddons_rangeTransform(SEXP, SEXP, SEXP);
 extern SEXP _mclustAddons_rowMax(SEXP);
 extern SEXP _mclustAddons_rowSum(SEXP);
-extern SEXP _mclustAddons_colMax(SEXP);
-extern SEXP _mclustAddons_colSum(SEXP);
-extern SEXP _mclustAddons_logsumexp_Rcpp(SEXP, SEXP);
 extern SEXP _mclustAddons_softmax_Rcpp(SEXP, SEXP);
+extern SEXP _mclustAddons_stable_exp_neg_diff(SEXP);
 
 static const R_CallMethodDef CallEntries[] = {
+    {"_mclustAddons_colMax",                       (DL_FUNC) &_mclustAddons_colMax,                       1},
+    {"_mclustAddons_colSum",                       (DL_FUNC) &_mclustAddons_colSum,                       1},
+    {"_mclustAddons_hypcube_lhs",                  (DL_FUNC) &_mclustAddons_hypcube_lhs,                  4},
+    {"_mclustAddons_hypcube_smc",                  (DL_FUNC) &_mclustAddons_hypcube_smc,                  4},
+    {"_mclustAddons_inside_range",                 (DL_FUNC) &_mclustAddons_inside_range,                 2},
+    {"_mclustAddons_logsumexp_Rcpp",               (DL_FUNC) &_mclustAddons_logsumexp_Rcpp,               2},
     {"_mclustAddons_powerTransform",               (DL_FUNC) &_mclustAddons_powerTransform,               3},
     {"_mclustAddons_rangepowerTransformDeriv_lb",  (DL_FUNC) &_mclustAddons_rangepowerTransformDeriv_lb,  4},
     {"_mclustAddons_rangepowerTransformDeriv_lub", (DL_FUNC) &_mclustAddons_rangepowerTransformDeriv_lub, 6},
@@ -32,10 +42,8 @@ static const R_CallMethodDef CallEntries[] = {
     {"_mclustAddons_rangeTransform",               (DL_FUNC) &_mclustAddons_rangeTransform,               3},
     {"_mclustAddons_rowMax",                       (DL_FUNC) &_mclustAddons_rowMax,                       1},
     {"_mclustAddons_rowSum",                       (DL_FUNC) &_mclustAddons_rowSum,                       1},
-    {"_mclustAddons_colMax",                       (DL_FUNC) &_mclustAddons_colMax,                       1},
-    {"_mclustAddons_colSum",                       (DL_FUNC) &_mclustAddons_colSum,                       1},
-    {"_mclustAddons_logsumexp_Rcpp",               (DL_FUNC) &_mclustAddons_logsumexp_Rcpp,               2},
     {"_mclustAddons_softmax_Rcpp",                 (DL_FUNC) &_mclustAddons_softmax_Rcpp,                 2},
+    {"_mclustAddons_stable_exp_neg_diff",          (DL_FUNC) &_mclustAddons_stable_exp_neg_diff,          1},
     {NULL, NULL, 0}
 };
 
